@@ -9,7 +9,6 @@ describe 'heat::db' do
         :db_max_retries          => '<SERVICE DEFAULT>',
         :connection              => 'sqlite:////var/lib/heat/heat.sqlite',
         :connection_recycle_time => '<SERVICE DEFAULT>',
-        :min_pool_size           => '<SERVICE DEFAULT>',
         :max_pool_size           => '<SERVICE DEFAULT>',
         :max_retries             => '<SERVICE DEFAULT>',
         :retry_interval          => '<SERVICE DEFAULT>',
@@ -25,7 +24,6 @@ describe 'heat::db' do
         {
           :database_connection              => 'mysql+pymysql://heat:heat@localhost/heat',
           :database_connection_recycle_time => '3601',
-          :database_min_pool_size           => '2',
           :database_max_pool_size           => '12',
           :database_max_retries             => '11',
           :database_retry_interval          => '11',
@@ -42,7 +40,6 @@ describe 'heat::db' do
         :db_max_retries          => '-1',
         :connection              => 'mysql+pymysql://heat:heat@localhost/heat',
         :connection_recycle_time => '3601',
-        :min_pool_size           => '2',
         :max_pool_size           => '12',
         :max_retries             => '11',
         :retry_interval          => '11',
